@@ -18,10 +18,6 @@
 #include <time.h>
 #include <unistd.h>
 
-#ifdef __linux__
-#include <sys/auxv.h>
-#endif
-
 static long slack = 60;
 #define SLEEP_PHASE 300
 static int nflag, vflag;
@@ -31,7 +27,7 @@ static int randdelay = 0;
 static int jitter = 0;
 static char *timefile;
 
-static sig_atomic_t alarm_rang = 0;
+static volatile sig_atomic_t alarm_rang = 0;
 
 static void
 wakeup(int sig)
@@ -329,13 +325,13 @@ main(int argc, char *argv[])
 			char weekstr[4];
 			struct tm *tm = localtime(&t);
 			strftime(weekstr, sizeof weekstr, "%a", tm);
-			printf("%s %s %2ldd%3ldh%3ldm%3lds ",
+			printf("%s %s %2dd%3dh%3dm%3ds ",
 			    isotime(tm),
 			    weekstr,
-			    ((t - now) / (60*60*24)),
-			    ((t - now) / (60*60)) % 24,
-			    ((t - now) / 60) % 60,
-			    (t - now) % 60);
+			    ((int)(t - now) / (60*60*24)),
+			    ((int)(t - now) / (60*60)) % 24,
+			    ((int)(t - now) / 60) % 60,
+			    (int)(t - now) % 60);
 			if(jitter) {
 				printf("(plus up to %ds for jitter)\n", jitter);
 			} else {
@@ -356,11 +352,11 @@ main(int argc, char *argv[])
 		printf("Snoozing until %s\n", isotime(tm));
 
 	// setup SIGALRM handler to force early execution
-	struct sigaction sa;
+	struct sigaction sa = { 0 };
 	sa.sa_handler = &wakeup;
 	sa.sa_flags = SA_RESTART;
 	sigfillset(&sa.sa_mask);
-	sigaction(SIGALRM, &sa, NULL);  // XXX error handling
+	sigaction(SIGALRM, &sa, NULL);
 
 	while (!alarm_rang) {
 		now = time(0);
